/* MediaPlayer.c generated by valac 0.56.19, the Vala compiler
 * generated from MediaPlayer.vala, do not modify */

/*
 * Copyright 2015-2017 elementary, Inc. (http://launchpad.net/wingpanel-indicator-sound)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Fiorotto Giuliano <mr.fiorotto@gmail.com>
 *              Fabio Zaramella <ffabio.96.x@gmail.com>
 */

#include "sound.h"
#include <glib.h>
#include <gio/gio.h>
#include <string.h>
#include <stdlib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

typedef GDBusProxy SoundServicesMediaPlayerProxy;
typedef GDBusProxyClass SoundServicesMediaPlayerProxyClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

static GType sound_services_media_player_get_type_once (void);
static void sound_services_media_player_proxy_g_signal (GDBusProxy* proxy,
                                                 const gchar* sender_name,
                                                 const gchar* signal_name,
                                                 GVariant* parameters);
static void sound_services_media_player_proxy_play (SoundServicesMediaPlayer* self,
                                             GError** error);
static void sound_services_media_player_proxy_pause (SoundServicesMediaPlayer* self,
                                              GError** error);
static void sound_services_media_player_proxy_stop (SoundServicesMediaPlayer* self,
                                             GError** error);
static void sound_services_media_player_proxy_next (SoundServicesMediaPlayer* self,
                                             GError** error);
static void sound_services_media_player_proxy_previous (SoundServicesMediaPlayer* self,
                                                 GError** error);
static void sound_services_media_player_proxy_fast_forward (SoundServicesMediaPlayer* self,
                                                     GError** error);
static void sound_services_media_player_proxy_rewind (SoundServicesMediaPlayer* self,
                                               GError** error);
static gchar* sound_services_media_player_dbus_proxy_get_name (SoundServicesMediaPlayer* self);
static gchar* sound_services_media_player_dbus_proxy_get_mediaplayer_type (SoundServicesMediaPlayer* self);
static gchar* sound_services_media_player_dbus_proxy_get_subtype (SoundServicesMediaPlayer* self);
static guint sound_services_media_player_dbus_proxy_get_position (SoundServicesMediaPlayer* self);
static gchar* sound_services_media_player_dbus_proxy_get_status (SoundServicesMediaPlayer* self);
static gchar* sound_services_media_player_dbus_proxy_get_equalizer (SoundServicesMediaPlayer* self);
static void sound_services_media_player_dbus_proxy_set_equalizer (SoundServicesMediaPlayer* self,
                                                           const gchar* value);
static gchar* sound_services_media_player_dbus_proxy_get_repeat (SoundServicesMediaPlayer* self);
static void sound_services_media_player_dbus_proxy_set_repeat (SoundServicesMediaPlayer* self,
                                                        const gchar* value);
static gchar* sound_services_media_player_dbus_proxy_get_shuffle (SoundServicesMediaPlayer* self);
static void sound_services_media_player_dbus_proxy_set_shuffle (SoundServicesMediaPlayer* self,
                                                         const gchar* value);
static gchar* sound_services_media_player_dbus_proxy_get_scan (SoundServicesMediaPlayer* self);
static void sound_services_media_player_dbus_proxy_set_scan (SoundServicesMediaPlayer* self,
                                                      const gchar* value);
static GHashTable* sound_services_media_player_dbus_proxy_get_track (SoundServicesMediaPlayer* self);
static char* sound_services_media_player_dbus_proxy_get_device (SoundServicesMediaPlayer* self);
static gboolean sound_services_media_player_dbus_proxy_get_browsable (SoundServicesMediaPlayer* self);
static gboolean sound_services_media_player_dbus_proxy_get_searchable (SoundServicesMediaPlayer* self);
static char* sound_services_media_player_dbus_proxy_get_playlist (SoundServicesMediaPlayer* self);
static void sound_services_media_player_proxy_sound_services_media_player_interface_init (SoundServicesMediaPlayerIface* iface);
static void _dbus_sound_services_media_player_play (SoundServicesMediaPlayer* self,
                                             GVariant* _parameters_,
                                             GDBusMethodInvocation* invocation);
static void _dbus_sound_services_media_player_pause (SoundServicesMediaPlayer* self,
                                              GVariant* _parameters_,
                                              GDBusMethodInvocation* invocation);
static void _dbus_sound_services_media_player_stop (SoundServicesMediaPlayer* self,
                                             GVariant* _parameters_,
                                             GDBusMethodInvocation* invocation);
static void _dbus_sound_services_media_player_next (SoundServicesMediaPlayer* self,
                                             GVariant* _parameters_,
                                             GDBusMethodInvocation* invocation);
static void _dbus_sound_services_media_player_previous (SoundServicesMediaPlayer* self,
                                                 GVariant* _parameters_,
                                                 GDBusMethodInvocation* invocation);
static void _dbus_sound_services_media_player_fast_forward (SoundServicesMediaPlayer* self,
                                                     GVariant* _parameters_,
                                                     GDBusMethodInvocation* invocation);
static void _dbus_sound_services_media_player_rewind (SoundServicesMediaPlayer* self,
                                               GVariant* _parameters_,
                                               GDBusMethodInvocation* invocation);
static void sound_services_media_player_dbus_interface_method_call (GDBusConnection* connection,
                                                             const gchar* sender,
                                                             const gchar* object_path,
                                                             const gchar* interface_name,
                                                             const gchar* method_name,
                                                             GVariant* parameters,
                                                             GDBusMethodInvocation* invocation,
                                                             gpointer user_data);
static GVariant* sound_services_media_player_dbus_interface_get_property (GDBusConnection* connection,
                                                                   const gchar* sender,
                                                                   const gchar* object_path,
                                                                   const gchar* interface_name,
                                                                   const gchar* property_name,
                                                                   GError** error,
                                                                   gpointer user_data);
static GVariant* _dbus_sound_services_media_player_get_name (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_mediaplayer_type (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_subtype (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_position (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_status (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_equalizer (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_repeat (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_shuffle (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_scan (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_track (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_device (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_browsable (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_searchable (SoundServicesMediaPlayer* self);
static GVariant* _dbus_sound_services_media_player_get_playlist (SoundServicesMediaPlayer* self);
static gboolean sound_services_media_player_dbus_interface_set_property (GDBusConnection* connection,
                                                                  const gchar* sender,
                                                                  const gchar* object_path,
                                                                  const gchar* interface_name,
                                                                  const gchar* property_name,
                                                                  GVariant* value,
                                                                  GError** error,
                                                                  gpointer user_data);
static void _dbus_sound_services_media_player_set_equalizer (SoundServicesMediaPlayer* self,
                                                      GVariant* _value);
static void _dbus_sound_services_media_player_set_repeat (SoundServicesMediaPlayer* self,
                                                   GVariant* _value);
static void _dbus_sound_services_media_player_set_shuffle (SoundServicesMediaPlayer* self,
                                                    GVariant* _value);
static void _dbus_sound_services_media_player_set_scan (SoundServicesMediaPlayer* self,
                                                 GVariant* _value);
static void _sound_services_media_player_unregister_object (gpointer user_data);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_play_in[] = {NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_play_out[] = {NULL};
static const GDBusMethodInfo _sound_services_media_player_dbus_method_info_play = {-1, "Play", (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_play_in), (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_play_out), NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_pause_in[] = {NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_pause_out[] = {NULL};
static const GDBusMethodInfo _sound_services_media_player_dbus_method_info_pause = {-1, "Pause", (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_pause_in), (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_pause_out), NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_stop_in[] = {NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_stop_out[] = {NULL};
static const GDBusMethodInfo _sound_services_media_player_dbus_method_info_stop = {-1, "Stop", (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_stop_in), (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_stop_out), NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_next_in[] = {NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_next_out[] = {NULL};
static const GDBusMethodInfo _sound_services_media_player_dbus_method_info_next = {-1, "Next", (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_next_in), (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_next_out), NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_previous_in[] = {NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_previous_out[] = {NULL};
static const GDBusMethodInfo _sound_services_media_player_dbus_method_info_previous = {-1, "Previous", (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_previous_in), (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_previous_out), NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_fast_forward_in[] = {NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_fast_forward_out[] = {NULL};
static const GDBusMethodInfo _sound_services_media_player_dbus_method_info_fast_forward = {-1, "FastForward", (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_fast_forward_in), (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_fast_forward_out), NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_rewind_in[] = {NULL};
static const GDBusArgInfo * const _sound_services_media_player_dbus_arg_info_rewind_out[] = {NULL};
static const GDBusMethodInfo _sound_services_media_player_dbus_method_info_rewind = {-1, "Rewind", (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_rewind_in), (GDBusArgInfo **) (&_sound_services_media_player_dbus_arg_info_rewind_out), NULL};
static const GDBusMethodInfo * const _sound_services_media_player_dbus_method_info[] = {&_sound_services_media_player_dbus_method_info_play, &_sound_services_media_player_dbus_method_info_pause, &_sound_services_media_player_dbus_method_info_stop, &_sound_services_media_player_dbus_method_info_next, &_sound_services_media_player_dbus_method_info_previous, &_sound_services_media_player_dbus_method_info_fast_forward, &_sound_services_media_player_dbus_method_info_rewind, NULL};
static const GDBusSignalInfo * const _sound_services_media_player_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_name = {-1, "Name", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_mediaplayer_type = {-1, "Type", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_subtype = {-1, "Subtype", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_position = {-1, "Position", "u", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_status = {-1, "Status", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_equalizer = {-1, "Equalizer", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_repeat = {-1, "Repeat", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_shuffle = {-1, "Shuffle", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_scan = {-1, "Scan", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_track = {-1, "Track", "a{sv}", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_device = {-1, "Device", "o", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_browsable = {-1, "Browsable", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_searchable = {-1, "Searchable", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _sound_services_media_player_dbus_property_info_playlist = {-1, "Playlist", "o", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo * const _sound_services_media_player_dbus_property_info[] = {&_sound_services_media_player_dbus_property_info_name, &_sound_services_media_player_dbus_property_info_mediaplayer_type, &_sound_services_media_player_dbus_property_info_subtype, &_sound_services_media_player_dbus_property_info_position, &_sound_services_media_player_dbus_property_info_status, &_sound_services_media_player_dbus_property_info_equalizer, &_sound_services_media_player_dbus_property_info_repeat, &_sound_services_media_player_dbus_property_info_shuffle, &_sound_services_media_player_dbus_property_info_scan, &_sound_services_media_player_dbus_property_info_track, &_sound_services_media_player_dbus_property_info_device, &_sound_services_media_player_dbus_property_info_browsable, &_sound_services_media_player_dbus_property_info_searchable, &_sound_services_media_player_dbus_property_info_playlist, NULL};
static const GDBusInterfaceInfo _sound_services_media_player_dbus_interface_info = {-1, "org.bluez.MediaPlayer1", (GDBusMethodInfo **) (&_sound_services_media_player_dbus_method_info), (GDBusSignalInfo **) (&_sound_services_media_player_dbus_signal_info), (GDBusPropertyInfo **) (&_sound_services_media_player_dbus_property_info), NULL};
static const GDBusInterfaceVTable _sound_services_media_player_dbus_interface_vtable = {sound_services_media_player_dbus_interface_method_call, sound_services_media_player_dbus_interface_get_property, sound_services_media_player_dbus_interface_set_property};

void
sound_services_media_player_play (SoundServicesMediaPlayer* self,
                                  GError** error)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->play) {
		_iface_->play (self, error);
	}
}

void
sound_services_media_player_pause (SoundServicesMediaPlayer* self,
                                   GError** error)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->pause) {
		_iface_->pause (self, error);
	}
}

void
sound_services_media_player_stop (SoundServicesMediaPlayer* self,
                                  GError** error)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->stop) {
		_iface_->stop (self, error);
	}
}

void
sound_services_media_player_next (SoundServicesMediaPlayer* self,
                                  GError** error)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->next) {
		_iface_->next (self, error);
	}
}

void
sound_services_media_player_previous (SoundServicesMediaPlayer* self,
                                      GError** error)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->previous) {
		_iface_->previous (self, error);
	}
}

void
sound_services_media_player_fast_forward (SoundServicesMediaPlayer* self,
                                          GError** error)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->fast_forward) {
		_iface_->fast_forward (self, error);
	}
}

void
sound_services_media_player_rewind (SoundServicesMediaPlayer* self,
                                    GError** error)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->rewind) {
		_iface_->rewind (self, error);
	}
}

gchar*
sound_services_media_player_get_name (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_name) {
		return _iface_->get_name (self);
	}
	return NULL;
}

gchar*
sound_services_media_player_get_mediaplayer_type (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_mediaplayer_type) {
		return _iface_->get_mediaplayer_type (self);
	}
	return NULL;
}

gchar*
sound_services_media_player_get_subtype (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_subtype) {
		return _iface_->get_subtype (self);
	}
	return NULL;
}

guint
sound_services_media_player_get_position (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, 0U);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_position) {
		return _iface_->get_position (self);
	}
	return 0U;
}

gchar*
sound_services_media_player_get_status (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_status) {
		return _iface_->get_status (self);
	}
	return NULL;
}

gchar*
sound_services_media_player_get_equalizer (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_equalizer) {
		return _iface_->get_equalizer (self);
	}
	return NULL;
}

void
sound_services_media_player_set_equalizer (SoundServicesMediaPlayer* self,
                                           const gchar* value)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->set_equalizer) {
		_iface_->set_equalizer (self, value);
	}
}

gchar*
sound_services_media_player_get_repeat (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_repeat) {
		return _iface_->get_repeat (self);
	}
	return NULL;
}

void
sound_services_media_player_set_repeat (SoundServicesMediaPlayer* self,
                                        const gchar* value)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->set_repeat) {
		_iface_->set_repeat (self, value);
	}
}

gchar*
sound_services_media_player_get_shuffle (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_shuffle) {
		return _iface_->get_shuffle (self);
	}
	return NULL;
}

void
sound_services_media_player_set_shuffle (SoundServicesMediaPlayer* self,
                                         const gchar* value)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->set_shuffle) {
		_iface_->set_shuffle (self, value);
	}
}

gchar*
sound_services_media_player_get_scan (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_scan) {
		return _iface_->get_scan (self);
	}
	return NULL;
}

void
sound_services_media_player_set_scan (SoundServicesMediaPlayer* self,
                                      const gchar* value)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->set_scan) {
		_iface_->set_scan (self, value);
	}
}

GHashTable*
sound_services_media_player_get_track (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_track) {
		return _iface_->get_track (self);
	}
	return NULL;
}

char*
sound_services_media_player_get_device (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_device) {
		return _iface_->get_device (self);
	}
	return NULL;
}

gboolean
sound_services_media_player_get_browsable (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_browsable) {
		return _iface_->get_browsable (self);
	}
	return FALSE;
}

gboolean
sound_services_media_player_get_searchable (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_searchable) {
		return _iface_->get_searchable (self);
	}
	return FALSE;
}

char*
sound_services_media_player_get_playlist (SoundServicesMediaPlayer* self)
{
	SoundServicesMediaPlayerIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = SOUND_SERVICES_MEDIA_PLAYER_GET_INTERFACE (self);
	if (_iface_->get_playlist) {
		return _iface_->get_playlist (self);
	}
	return NULL;
}

static void
sound_services_media_player_default_init (SoundServicesMediaPlayerIface * iface,
                                          gpointer iface_data)
{
}

static GType
sound_services_media_player_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SoundServicesMediaPlayerIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sound_services_media_player_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType sound_services_media_player_type_id;
	sound_services_media_player_type_id = g_type_register_static (G_TYPE_INTERFACE, "SoundServicesMediaPlayer", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (sound_services_media_player_type_id, G_TYPE_OBJECT);
	g_type_set_qdata (sound_services_media_player_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) sound_services_media_player_proxy_get_type);
	g_type_set_qdata (sound_services_media_player_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.bluez.MediaPlayer1");
	g_type_set_qdata (sound_services_media_player_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_sound_services_media_player_dbus_interface_info));
	g_type_set_qdata (sound_services_media_player_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) sound_services_media_player_register_object);
	return sound_services_media_player_type_id;
}

GType
sound_services_media_player_get_type (void)
{
	static volatile gsize sound_services_media_player_type_id__once = 0;
	if (g_once_init_enter (&sound_services_media_player_type_id__once)) {
		GType sound_services_media_player_type_id;
		sound_services_media_player_type_id = sound_services_media_player_get_type_once ();
		g_once_init_leave (&sound_services_media_player_type_id__once, sound_services_media_player_type_id);
	}
	return sound_services_media_player_type_id__once;
}

G_DEFINE_TYPE_EXTENDED (SoundServicesMediaPlayerProxy, sound_services_media_player_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (SOUND_SERVICES_TYPE_MEDIA_PLAYER, sound_services_media_player_proxy_sound_services_media_player_interface_init) )
static void
sound_services_media_player_proxy_class_init (SoundServicesMediaPlayerProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = sound_services_media_player_proxy_g_signal;
}

static void
sound_services_media_player_proxy_g_signal (GDBusProxy* proxy,
                                            const gchar* sender_name,
                                            const gchar* signal_name,
                                            GVariant* parameters)
{
}

static void
sound_services_media_player_proxy_init (SoundServicesMediaPlayerProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_sound_services_media_player_dbus_interface_info));
}

static void
sound_services_media_player_proxy_play (SoundServicesMediaPlayer* self,
                                        GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.MediaPlayer1", "Play");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
sound_services_media_player_proxy_pause (SoundServicesMediaPlayer* self,
                                         GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.MediaPlayer1", "Pause");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
sound_services_media_player_proxy_stop (SoundServicesMediaPlayer* self,
                                        GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.MediaPlayer1", "Stop");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
sound_services_media_player_proxy_next (SoundServicesMediaPlayer* self,
                                        GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.MediaPlayer1", "Next");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
sound_services_media_player_proxy_previous (SoundServicesMediaPlayer* self,
                                            GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.MediaPlayer1", "Previous");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
sound_services_media_player_proxy_fast_forward (SoundServicesMediaPlayer* self,
                                                GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.MediaPlayer1", "FastForward");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
sound_services_media_player_proxy_rewind (SoundServicesMediaPlayer* self,
                                          GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.MediaPlayer1", "Rewind");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static gchar*
sound_services_media_player_dbus_proxy_get_name (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Name");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Name"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
sound_services_media_player_dbus_proxy_get_mediaplayer_type (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Type");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Type"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
sound_services_media_player_dbus_proxy_get_subtype (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Subtype");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Subtype"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static guint
sound_services_media_player_dbus_proxy_get_position (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	guint _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Position");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Position"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			guint _tmp57_ = 0U;
			return _tmp57_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_uint32 (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
sound_services_media_player_dbus_proxy_get_status (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Status");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Status"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
sound_services_media_player_dbus_proxy_get_equalizer (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Equalizer");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Equalizer"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
sound_services_media_player_dbus_proxy_set_equalizer (SoundServicesMediaPlayer* self,
                                                      const gchar* value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Equalizer"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static gchar*
sound_services_media_player_dbus_proxy_get_repeat (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Repeat");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Repeat"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
sound_services_media_player_dbus_proxy_set_repeat (SoundServicesMediaPlayer* self,
                                                   const gchar* value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Repeat"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static gchar*
sound_services_media_player_dbus_proxy_get_shuffle (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Shuffle");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Shuffle"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
sound_services_media_player_dbus_proxy_set_shuffle (SoundServicesMediaPlayer* self,
                                                    const gchar* value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Shuffle"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static gchar*
sound_services_media_player_dbus_proxy_get_scan (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Scan");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Scan"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
sound_services_media_player_dbus_proxy_set_scan (SoundServicesMediaPlayer* self,
                                                 const gchar* value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Scan"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static GHashTable*
sound_services_media_player_dbus_proxy_get_track (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	GHashTable* _result;
	GHashTable* _tmp58_;
	GVariantIter _tmp59_;
	GVariant* _tmp60_;
	GVariant* _tmp61_;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Track");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Track"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_tmp58_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_variant_unref);
	g_variant_iter_init (&_tmp59_, _inner_reply);
	while (g_variant_iter_loop (&_tmp59_, "{?*}", &_tmp60_, &_tmp61_)) {
		g_hash_table_insert (_tmp58_, g_variant_dup_string (_tmp60_, NULL), g_variant_get_variant (_tmp61_));
	}
	_result = _tmp58_;
	g_variant_unref (_inner_reply);
	return _result;
}

static char*
sound_services_media_player_dbus_proxy_get_device (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	char* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Device");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Device"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
sound_services_media_player_dbus_proxy_get_browsable (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Browsable");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Browsable"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp62_ = FALSE;
			return _tmp62_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
sound_services_media_player_dbus_proxy_get_searchable (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Searchable");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Searchable"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp63_ = FALSE;
			return _tmp63_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static char*
sound_services_media_player_dbus_proxy_get_playlist (SoundServicesMediaPlayer* self)
{
	GVariant *_inner_reply;
	char* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Playlist");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.MediaPlayer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Playlist"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
sound_services_media_player_proxy_sound_services_media_player_interface_init (SoundServicesMediaPlayerIface* iface)
{
	iface->play = sound_services_media_player_proxy_play;
	iface->pause = sound_services_media_player_proxy_pause;
	iface->stop = sound_services_media_player_proxy_stop;
	iface->next = sound_services_media_player_proxy_next;
	iface->previous = sound_services_media_player_proxy_previous;
	iface->fast_forward = sound_services_media_player_proxy_fast_forward;
	iface->rewind = sound_services_media_player_proxy_rewind;
	iface->get_name = sound_services_media_player_dbus_proxy_get_name;
	iface->get_mediaplayer_type = sound_services_media_player_dbus_proxy_get_mediaplayer_type;
	iface->get_subtype = sound_services_media_player_dbus_proxy_get_subtype;
	iface->get_position = sound_services_media_player_dbus_proxy_get_position;
	iface->get_status = sound_services_media_player_dbus_proxy_get_status;
	iface->get_equalizer = sound_services_media_player_dbus_proxy_get_equalizer;
	iface->set_equalizer = sound_services_media_player_dbus_proxy_set_equalizer;
	iface->get_repeat = sound_services_media_player_dbus_proxy_get_repeat;
	iface->set_repeat = sound_services_media_player_dbus_proxy_set_repeat;
	iface->get_shuffle = sound_services_media_player_dbus_proxy_get_shuffle;
	iface->set_shuffle = sound_services_media_player_dbus_proxy_set_shuffle;
	iface->get_scan = sound_services_media_player_dbus_proxy_get_scan;
	iface->set_scan = sound_services_media_player_dbus_proxy_set_scan;
	iface->get_track = sound_services_media_player_dbus_proxy_get_track;
	iface->get_device = sound_services_media_player_dbus_proxy_get_device;
	iface->get_browsable = sound_services_media_player_dbus_proxy_get_browsable;
	iface->get_searchable = sound_services_media_player_dbus_proxy_get_searchable;
	iface->get_playlist = sound_services_media_player_dbus_proxy_get_playlist;
}

static void
_dbus_sound_services_media_player_play (SoundServicesMediaPlayer* self,
                                        GVariant* _parameters_,
                                        GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	sound_services_media_player_play (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_sound_services_media_player_pause (SoundServicesMediaPlayer* self,
                                         GVariant* _parameters_,
                                         GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	sound_services_media_player_pause (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_sound_services_media_player_stop (SoundServicesMediaPlayer* self,
                                        GVariant* _parameters_,
                                        GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	sound_services_media_player_stop (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_sound_services_media_player_next (SoundServicesMediaPlayer* self,
                                        GVariant* _parameters_,
                                        GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	sound_services_media_player_next (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_sound_services_media_player_previous (SoundServicesMediaPlayer* self,
                                            GVariant* _parameters_,
                                            GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	sound_services_media_player_previous (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_sound_services_media_player_fast_forward (SoundServicesMediaPlayer* self,
                                                GVariant* _parameters_,
                                                GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	sound_services_media_player_fast_forward (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_sound_services_media_player_rewind (SoundServicesMediaPlayer* self,
                                          GVariant* _parameters_,
                                          GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	sound_services_media_player_rewind (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
sound_services_media_player_dbus_interface_method_call (GDBusConnection* connection,
                                                        const gchar* sender,
                                                        const gchar* object_path,
                                                        const gchar* interface_name,
                                                        const gchar* method_name,
                                                        GVariant* parameters,
                                                        GDBusMethodInvocation* invocation,
                                                        gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "Play") == 0) {
		_dbus_sound_services_media_player_play (object, parameters, invocation);
	} else if (strcmp (method_name, "Pause") == 0) {
		_dbus_sound_services_media_player_pause (object, parameters, invocation);
	} else if (strcmp (method_name, "Stop") == 0) {
		_dbus_sound_services_media_player_stop (object, parameters, invocation);
	} else if (strcmp (method_name, "Next") == 0) {
		_dbus_sound_services_media_player_next (object, parameters, invocation);
	} else if (strcmp (method_name, "Previous") == 0) {
		_dbus_sound_services_media_player_previous (object, parameters, invocation);
	} else if (strcmp (method_name, "FastForward") == 0) {
		_dbus_sound_services_media_player_fast_forward (object, parameters, invocation);
	} else if (strcmp (method_name, "Rewind") == 0) {
		_dbus_sound_services_media_player_rewind (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
_dbus_sound_services_media_player_get_name (SoundServicesMediaPlayer* self)
{
	gchar* result;
	GVariant* _reply;
	result = sound_services_media_player_get_name (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_mediaplayer_type (SoundServicesMediaPlayer* self)
{
	gchar* result;
	GVariant* _reply;
	result = sound_services_media_player_get_mediaplayer_type (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_subtype (SoundServicesMediaPlayer* self)
{
	gchar* result;
	GVariant* _reply;
	result = sound_services_media_player_get_subtype (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_position (SoundServicesMediaPlayer* self)
{
	guint result;
	GVariant* _reply;
	result = sound_services_media_player_get_position (self);
	_reply = g_variant_new_uint32 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_status (SoundServicesMediaPlayer* self)
{
	gchar* result;
	GVariant* _reply;
	result = sound_services_media_player_get_status (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_equalizer (SoundServicesMediaPlayer* self)
{
	gchar* result;
	GVariant* _reply;
	result = sound_services_media_player_get_equalizer (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_repeat (SoundServicesMediaPlayer* self)
{
	gchar* result;
	GVariant* _reply;
	result = sound_services_media_player_get_repeat (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_shuffle (SoundServicesMediaPlayer* self)
{
	gchar* result;
	GVariant* _reply;
	result = sound_services_media_player_get_shuffle (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_scan (SoundServicesMediaPlayer* self)
{
	gchar* result;
	GVariant* _reply;
	result = sound_services_media_player_get_scan (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_track (SoundServicesMediaPlayer* self)
{
	GHashTable* result;
	GVariant* _reply;
	GVariantBuilder _tmp64_;
	GHashTableIter _tmp65_;
	gpointer _tmp66_;
	gpointer _tmp67_;
	result = sound_services_media_player_get_track (self);
	g_hash_table_iter_init (&_tmp65_, result);
	g_variant_builder_init (&_tmp64_, G_VARIANT_TYPE ("a{sv}"));
	while (g_hash_table_iter_next (&_tmp65_, &_tmp66_, &_tmp67_)) {
		gchar* _key;
		GVariant* _value;
		_key = (gchar*) _tmp66_;
		_value = (GVariant*) _tmp67_;
		g_variant_builder_add (&_tmp64_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
	}
	_reply = g_variant_builder_end (&_tmp64_);
	_g_hash_table_unref0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_device (SoundServicesMediaPlayer* self)
{
	char* result;
	GVariant* _reply;
	result = sound_services_media_player_get_device (self);
	_reply = g_variant_new_object_path (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_browsable (SoundServicesMediaPlayer* self)
{
	gboolean result;
	GVariant* _reply;
	result = sound_services_media_player_get_browsable (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_searchable (SoundServicesMediaPlayer* self)
{
	gboolean result;
	GVariant* _reply;
	result = sound_services_media_player_get_searchable (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_sound_services_media_player_get_playlist (SoundServicesMediaPlayer* self)
{
	char* result;
	GVariant* _reply;
	result = sound_services_media_player_get_playlist (self);
	_reply = g_variant_new_object_path (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
sound_services_media_player_dbus_interface_get_property (GDBusConnection* connection,
                                                         const gchar* sender,
                                                         const gchar* object_path,
                                                         const gchar* interface_name,
                                                         const gchar* property_name,
                                                         GError** error,
                                                         gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "Name") == 0) {
		return _dbus_sound_services_media_player_get_name (object);
	} else if (strcmp (property_name, "Type") == 0) {
		return _dbus_sound_services_media_player_get_mediaplayer_type (object);
	} else if (strcmp (property_name, "Subtype") == 0) {
		return _dbus_sound_services_media_player_get_subtype (object);
	} else if (strcmp (property_name, "Position") == 0) {
		return _dbus_sound_services_media_player_get_position (object);
	} else if (strcmp (property_name, "Status") == 0) {
		return _dbus_sound_services_media_player_get_status (object);
	} else if (strcmp (property_name, "Equalizer") == 0) {
		return _dbus_sound_services_media_player_get_equalizer (object);
	} else if (strcmp (property_name, "Repeat") == 0) {
		return _dbus_sound_services_media_player_get_repeat (object);
	} else if (strcmp (property_name, "Shuffle") == 0) {
		return _dbus_sound_services_media_player_get_shuffle (object);
	} else if (strcmp (property_name, "Scan") == 0) {
		return _dbus_sound_services_media_player_get_scan (object);
	} else if (strcmp (property_name, "Track") == 0) {
		return _dbus_sound_services_media_player_get_track (object);
	} else if (strcmp (property_name, "Device") == 0) {
		return _dbus_sound_services_media_player_get_device (object);
	} else if (strcmp (property_name, "Browsable") == 0) {
		return _dbus_sound_services_media_player_get_browsable (object);
	} else if (strcmp (property_name, "Searchable") == 0) {
		return _dbus_sound_services_media_player_get_searchable (object);
	} else if (strcmp (property_name, "Playlist") == 0) {
		return _dbus_sound_services_media_player_get_playlist (object);
	}
	return NULL;
}

static void
_dbus_sound_services_media_player_set_equalizer (SoundServicesMediaPlayer* self,
                                                 GVariant* _value)
{
	gchar* value = NULL;
	value = g_variant_dup_string (_value, NULL);
	sound_services_media_player_set_equalizer (self, value);
	_g_free0 (value);
}

static void
_dbus_sound_services_media_player_set_repeat (SoundServicesMediaPlayer* self,
                                              GVariant* _value)
{
	gchar* value = NULL;
	value = g_variant_dup_string (_value, NULL);
	sound_services_media_player_set_repeat (self, value);
	_g_free0 (value);
}

static void
_dbus_sound_services_media_player_set_shuffle (SoundServicesMediaPlayer* self,
                                               GVariant* _value)
{
	gchar* value = NULL;
	value = g_variant_dup_string (_value, NULL);
	sound_services_media_player_set_shuffle (self, value);
	_g_free0 (value);
}

static void
_dbus_sound_services_media_player_set_scan (SoundServicesMediaPlayer* self,
                                            GVariant* _value)
{
	gchar* value = NULL;
	value = g_variant_dup_string (_value, NULL);
	sound_services_media_player_set_scan (self, value);
	_g_free0 (value);
}

static gboolean
sound_services_media_player_dbus_interface_set_property (GDBusConnection* connection,
                                                         const gchar* sender,
                                                         const gchar* object_path,
                                                         const gchar* interface_name,
                                                         const gchar* property_name,
                                                         GVariant* value,
                                                         GError** error,
                                                         gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "Equalizer") == 0) {
		_dbus_sound_services_media_player_set_equalizer (object, value);
		return TRUE;
	} else if (strcmp (property_name, "Repeat") == 0) {
		_dbus_sound_services_media_player_set_repeat (object, value);
		return TRUE;
	} else if (strcmp (property_name, "Shuffle") == 0) {
		_dbus_sound_services_media_player_set_shuffle (object, value);
		return TRUE;
	} else if (strcmp (property_name, "Scan") == 0) {
		_dbus_sound_services_media_player_set_scan (object, value);
		return TRUE;
	}
	return FALSE;
}

guint
sound_services_media_player_register_object (gpointer object,
                                             GDBusConnection* connection,
                                             const gchar* path,
                                             GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_sound_services_media_player_dbus_interface_info), &_sound_services_media_player_dbus_interface_vtable, data, _sound_services_media_player_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}

static void
_sound_services_media_player_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

